# Versioning and Changelog

The changelog is prepared manually immediately before a release. Each changelog entry should follow this structure:

```md
## 2.0.0 - 2018-05-07

### Breaking changes

- A change ([#100](https://github.com/shopify/polaris/pull/100))
```

The possible groups in which to categorize changes are:

- Breaking changes
- New components
- Enhancements (new variations, accessibility improvements, etc.)
- Design updates (non-breaking design changes implemented in code)
- Bug fixes
- Documentation
- Dependency upgrades

## Out of scope for CHANGELOG.md

Generally, changes related to these topics can be omitted:

- Style guide (update the [“What’s new” page](https://github.com/Shopify/polaris-styleguide/tree/master/pages/whats-new) instead)
- Sketch UIKit (unless noteworthy)
- Dev dependencies upgrades
- Chores (infrastructure, release process…)

## Unreleased changes

Unreleased changes must go under the `## Unreleased` section (inspired by <https://keepachangelog.com>):

```md
## Unreleased

### Bug fixes

- Fixed something ([#100](https://github.com/shopify/polaris/pull/100))
```

This heading must be commented (leaving it for an easy future use) when publishing a release:

```md
<!-- ## Unreleased -->
```

## Versioning scheme

Because we expose both React components (for which the markup, including class names, is an implementation detail) and static CSS/Sass builds, the versioning scheme for Polaris is somewhat unusual. The following sections detail what kinds of changes result in each of major, minor, and patch version bumps:

### Major

- Removal of a component
- Removal of a prop from a component
- Change to the type accepted for a prop
- Breaking changes to minimum version of dependencies
- Breaking changes to Sass functions and mixins

### Minor

- Breaking change to the HTML generated by a component, including addition, removal, or renaming of classes
- New component
- New prop for a component
- Additional type accepted for a prop
- Changes to the UI Kit that do not result in breaking changes

### Patch

- Bug fixes that do not result in breaking changes to markup
- Non-breaking changes to minimum version of dependencies
